@@ -177,13 +177,15 @@ get_summary.reg_fit_mediation <- function(object, boot = NULL, ...) {
   p_m <- length(m)
   covariates <- object$covariates
   robust <- object$robust
+  median <- object$median
   have_boot <- !is.null(boot)
   # compute summary of y ~ m + x + covariates
-  summary_ymx <- summary(object$fit_ymx)
+  if (median) summary_ymx <- summary(object$fit_ymx, se = "iid")
+  else summary_ymx <- summary(object$fit_ymx)
   # extract number of observations
   n <- nobs(object$fit_ymx)
   # perform tests for significance of effects
-  if(have_boot) {
+  if (have_boot) {
     # extract coefficients and add coefficients of covariates
     coefficients <- c(coefficients(object),
                       coef(object$fit_ymx)[-seq_len(p_m + 2L)])
@@ -205,20 +207,22 @@ get_summary.reg_fit_mediation <- function(object, boot = NULL, ...) {
     c_prime <- coefficients[2L * p_m + 2L, , drop = FALSE]
   } else {
     # compute summaries of regression models and extract t-tests for coefficients
-    if(p_m == 1L) {
-      summary_mx <- summary(object$fit_mx)
+    if (p_m == 1L) {
+      if (median) summary_mx <- summary(object$fit_mx, se = "iid")
+      else summary_mx <- summary(object$fit_mx)
       a <- summary_mx$coefficients[2L, , drop = FALSE]
       b <- summary_ymx$coefficients[2L, , drop = FALSE]
       c <- summary_ymx$coefficients[3L, , drop = FALSE]
     } else {
-      summary_mx <- lapply(object$fit_mx, summary)
+      if (median) summary_mx <- lapply(object$fit_mx, summary, se = "iid")
+      else summary_mx <- lapply(object$fit_mx, summary)
       a <- lapply(summary_mx, function(s) s$coefficients[2L, , drop = FALSE])
       a <- do.call(rbind, a)
       rownames(a) <- paste(m, x, sep = "~")
       b <- summary_ymx$coefficients[1L + seq_len(p_m), , drop = FALSE]
       c <- summary_ymx$coefficients[p_m + 2L, , drop = FALSE]
     }
-    if(robust) {
+    if (robust) {
       # standard errors and t-test not available
       c_prime <- matrix(c(object$c_prime, rep.int(NA_real_, 3L)), nrow = 1L)
       dimnames(c_prime) <- dimnames(c)
@@ -230,8 +234,8 @@ get_summary.reg_fit_mediation <- function(object, boot = NULL, ...) {
   # initialize return object
   result <- list(a = a, b = b, c = c, c_prime = c_prime)
   # add partial effects of control variables if they exist
-  if(length(covariates) > 0L) {
-    if(have_boot) {
+  if (length(covariates) > 0L) {
+    if (have_boot) {
       remove <- seq_len(2L * p_m + 2L)
       result$covariate_effects <- coefficients[-remove, , drop = FALSE]
     } else {
@@ -239,23 +243,27 @@ get_summary.reg_fit_mediation <- function(object, boot = NULL, ...) {
       result$covariate_effects <- summary_ymx$coefficients[-remove, , drop=FALSE]
     }
   }
-  # add residual standard error
+  # add robustness information
   result$robust <- robust
-  result$s <- list(value = summary_ymx$sigma, df = summary_ymx$df[2L])
-  # add (robust) R-squared
-  result$R2 <- list(R2 = summary_ymx$r.squared,
-                    adj_R2 = summary_ymx$adj.r.squared)
-  # add (robust) F-test
-  if(robust) {
-    # compute robust F-test for robust fit
-    result$F_test <- rob_F_test(object)
-  } else {
-    # add F-test for nonrobust fit
-    statistic <- unname(summary_ymx$fstatistic[1L])
-    df <- as.integer(summary_ymx$fstatistic[-1L])
-    p_value <- pf(statistic, df[1L], df[2L], lower.tail = FALSE)
-    result$F_test <- list(statistic = statistic, df = df,
-                          p_value = p_value)
+  result$median <- median
+  if (!median) {
+    # add residual standard error
+    result$s <- list(value = summary_ymx$sigma, df = summary_ymx$df[2L])
+    # add (robust) R-squared
+    result$R2 <- list(R2 = summary_ymx$r.squared,
+                      adj_R2 = summary_ymx$adj.r.squared)
+    # add (robust) F-test
+    if (robust) {
+      # compute robust F-test for robust fit
+      result$F_test <- rob_F_test(object)
+    } else {
+      # add F-test for nonrobust fit
+      statistic <- unname(summary_ymx$fstatistic[1L])
+      df <- as.integer(summary_ymx$fstatistic[-1L])
+      p_value <- pf(statistic, df[1L], df[2L], lower.tail = FALSE)
+      result$F_test <- list(statistic = statistic, df = df,
+                            p_value = p_value)
+    }
   }
   # add number of observations and variable names
   result <- c(result, list(n = n, x = x, y = y, m = m, covariates = covariates))
