@@ -8,10 +8,10 @@
 #' Perform (robust) mediation analysis via a (fast and robust) bootstrap test
 #' or Sobel's test.
 #'
-#' If \code{method} is \code{"regression"} and \code{robust} is \code{TRUE}
-#' (the default), the tests are based on robust regressions with
-#' \code{\link[robustbase]{lmrob}}.  The bootstrap test is thereby performed
-#' via the fast and robust bootstrap.
+#' If \code{method} is \code{"regression"}, \code{robust} is \code{TRUE} and
+#' \code{median} is \code{FALSE} (the defaults), the tests are based on robust
+#' regressions with \code{\link[robustbase]{lmrob}}.  The bootstrap test is
+#' thereby performed via the fast and robust bootstrap.
 #'
 #' Note that the regression estimator implemented in
 #' \code{\link[robustbase]{lmrob}} can be seen as weighted least squares
@@ -23,13 +23,20 @@
 #' correction is to account for the additional uncertainty of obtaining the
 #' robustness weights.
 #'
+#' If \code{method} is \code{"regression"}, \code{robust} is \code{TRUE} and
+#' \code{median} is \code{TRUE}, the tests are based on median regressions with
+#' \code{\link[quantreg]{rq}} and the standard bootstrap ().  Unlike the robust
+#' regressions described above, median regressions are not robust against
+#' outliers in the explanatory variables, and the standard bootstrap can suffer
+#' from oversampling of outliers in the bootstrap samples.
+#'
 #' If \code{method} is \code{"covariance"} and \code{robust} is \code{TRUE},
 #' the tests are based on a Huber M-estimator of location and scatter.  For the
 #' bootstrap test, the M-estimates are used to first clean the data via a
 #' transformation.  Then the standard bootstrap is performed with the cleaned
 #' data.  Note that this covariance-based approach is less robust than the
-#' regression-based one described above.  Furthermore, the bootstrap does not
-#' account for the variability from cleaning the data.
+#' approach based on robust regressions described above.  Furthermore, the
+#' bootstrap does not account for the variability from cleaning the data.
 #'
 #' \code{robmed} is a wrapper function for performing robust mediation analysis
 #' via regressions and the fast and robust bootstrap.
@@ -75,12 +82,19 @@
 #' \code{covariates}.
 #' @param robust  a logical indicating whether to perform a robust test
 #' (defaults to \code{TRUE}).
-#' @param control  if \code{robust} is \code{TRUE} and \code{method} is
-#' \code{"regression"}, a list of tuning parameters for
-#' \code{\link[robustbase]{lmrob}} as generated by
-#' \code{\link{reg_control}}.  If \code{robust} is \code{TRUE}
-#' and \code{method} is \code{"covariance"}, a list of tuning parameters for
-#' \code{\link{cov_Huber}} as generated by \code{\link{cov_control}}.
+#' @param median  a logical indicating if the effects should be estimated via
+#' median regression (defaults to \code{FALSE}).  This is ignored unless
+#' \code{method} is \code{"regression"} and \code{robust} is \code{TRUE}.
+#' @param control  a list of tuning parameters for the corresponding robust
+#' method.  For robust regression (\code{method = "regression"},
+#' \code{robust = TRUE} and \code{median = FALSE}), a list of tuning
+#' parameters for \code{\link[robustbase]{lmrob}} as generated by
+#' \code{\link{reg_control}}.  For Huberized covariance matrix estimation
+#' (\code{method = "covariance"} and \code{robust = TRUE}), a list of tuning
+#' parameters for \code{\link{cov_Huber}} as generated by
+#' \code{\link{cov_control}}.  No tuning parameters are necessary for median
+#' regression (\code{method = "regression"}, \code{robust = TRUE} and
+#' \code{median = TRUE}).
 #' @param \dots  additional arguments to be passed down.  For the bootstrap
 #' tests, those can be used to specify arguments of \code{\link[boot]{boot}},
 #' for example for parallel computing.
@@ -145,6 +159,10 @@
 #' structural equation models. \emph{Sociological Methodology}, \bold{13},
 #' 290--312.
 #'
+#' Yuan, Y. and MacKinnon, D.P. (2014) Robust mediation analysis based on
+#' median regression. \emph{Psychological Methods}, \bold{19}(1),
+#' 1--20.
+#'
 #' Zu, J. and Yuan, K.-H. (2010) Local influence and robust procedures for
 #' mediation analysis. \emph{Multivariate Behavioral Research}, \bold{45}(1),
 #' 1--44.
@@ -171,6 +189,7 @@
 #'
 #' @import boot
 #' @import robustbase
+#' @importFrom quantreg rq.fit
 #' @export
 
 test_mediation <- function(data, ...) UseMethod("test_mediation")
@@ -186,13 +205,15 @@ test_mediation.default <- function(data, x, y, m, covariates = NULL,
                                    R = 5000, level = 0.95,
                                    type = c("bca", "perc"),
                                    method = c("regression", "covariance"),
-                                   robust = TRUE, control, ...) {
+                                   robust = TRUE, median = FALSE, control,
+                                   ...) {
   ## fit mediation model
-  fit <- fit_mediation(data, x=x, y=y, m=m, covariates=covariates,
-                       method=method, robust=robust, control=control)
+  fit <- fit_mediation(data, x = x, y = y, m = m, covariates = covariates,
+                       method = method, robust = robust, median = median,
+                       control = control)
   ## call method for fitted model
-  test_mediation(fit, test=test, alternative=alternative,
-                 R=R, level=level, type=type, ...)
+  test_mediation(fit, test = test, alternative = alternative,
+                 R = R, level = level, type = type, ...)
 }
 
 
@@ -209,23 +230,23 @@ test_mediation.fit_mediation <- function(data, test = c("boot", "sobel"),
   test <- match.arg(test)
   alternative <- match.arg(alternative)
   p_m <- length(data$m)
-  if(p_m > 1L && test == "sobel") {
+  if (p_m > 1L && test == "sobel") {
     test <- "boot"
     warning("Sobel test not available with multiple mediators; ",
             "using bootstrap test")
   }
   ## perform mediation analysis
-  if(test == "boot") {
+  if (test == "boot") {
     # further inizializations
-    level <- rep(as.numeric(level), length.out=1)
-    if(is.na(level) || level < 0 || level > 1) level <- formals()$level
+    level <- rep(as.numeric(level), length.out = 1)
+    if (is.na(level) || level < 0 || level > 1) level <- formals()$level
     type <- match.arg(type)
     # perform bootstrap test
-    boot_test_mediation(data, alternative=alternative, R=R,
-                        level=level, type=type, ...)
-  } else if(test == "sobel") {
+    boot_test_mediation(data, alternative = alternative, R = R,
+                        level = level, type = type, ...)
+  } else if (test == "sobel") {
     # perform Sobel test
-    sobel_test_mediation(data, alternative=alternative)
+    sobel_test_mediation(data, alternative = alternative)
   } else stop("test not implemented")
 }
 
@@ -234,8 +255,9 @@ test_mediation.fit_mediation <- function(data, test = c("boot", "sobel"),
 #' @export
 
 robmed <- function(..., test = "boot", method = "regression",
-                   robust = TRUE) {
-  test_mediation(..., test="boot", method="regression", robust=TRUE)
+                   robust = TRUE, median = FALSE) {
+  test_mediation(..., test = "boot", method = "regression",
+                 robust = TRUE, median = FALSE)
 }
 
 
@@ -243,8 +265,9 @@ robmed <- function(..., test = "boot", method = "regression",
 #' @export
 
 indirect <- function(..., test = "boot", method = "regression",
-                     robust = FALSE) {
-  test_mediation(..., test="boot", method="regression", robust=FALSE)
+                     robust = FALSE, median = FALSE) {
+  test_mediation(..., test = "boot", method = "regression",
+                 robust = FALSE, median = FALSE)
 }
 
 
@@ -254,7 +277,7 @@ boot_test_mediation <- function(fit,
                                 R = 5000, level = 0.95, type = c("bca", "perc"),
                                 ...) {
   p_m <- length(fit$m)  # number of mediators
-  if(inherits(fit, "reg_fit_mediation")) {
+  if (inherits(fit, "reg_fit_mediation")) {
     # indices of mediators in data matrix to be used in bootstrap
     j_m <- match(fit$m, names(fit$data)) + 1L
     # indices of covariates in data matrix to be used in bootstrap
@@ -265,142 +288,208 @@ boot_test_mediation <- function(fit,
     # check if fast and robust bootstrap should be applied
     if(fit$robust) {
 
-      # This implementation uses the simpler approximation of
-      # Salibian-Barrera & Van Aelst (2008) rather than that of
-      # Salibian-Barrera & Zamar (2002).  The difference is that
-      # the latter also requires a correction of the residual scale.
+      # the fast and robust bootstrap does not work for median regression
 
-      # extract regression models
-      fit_mx <- fit$fit_mx
-      fit_ymx <- fit$fit_ymx
-      # extract control object from robust regressions
-      # (necessary to compute correction matrices)
-      psi_control <- get_psi_control(fit_ymx)  # the same for all model fits
-      if(p_m == 1L) {
-        # only one mediator
-        # extract (square root of) robustness weights and combine data
-        w_m <- sqrt(weights(fit_mx, type="robustness"))
-        w_y <- sqrt(weights(fit_ymx, type="robustness"))
-        # compute matrices for linear corrections
-        corr_m <- correction_matrix(z[, c(1L, 2L, j_covariates)],
-                                    weights=w_m,
-                                    residuals=residuals(fit_mx),
-                                    scale=fit_mx$scale,
-                                    control=psi_control)
-        coef_m <- coef(fit_mx)
-        corr_y <- correction_matrix(z[, c(1L, 4L, 2L, j_covariates)],
-                                    weights=w_y,
-                                    residuals=residuals(fit_ymx),
-                                    scale=fit_ymx$scale,
-                                    control=psi_control)
-        coef_y <- coef(fit_ymx)
-        # perform fast and robust bootstrap
-        robust_bootstrap <- function(z, i, w_m, corr_m, coef_m,
-                                     w_y, corr_y, coef_y) {
-          # extract bootstrap sample from the data
-          z_i <- z[i, , drop=FALSE]
-          w_m_i <- w_m[i]
-          w_y_i <- w_y[i]
-          # check whether there are enough observations with nonzero weights
-          if(sum(w_m_i > 0) <= 2 || sum(w_y_i > 0) <= 3) return(NA)
-          # compute coefficients from weighted regression m ~ x + covariates
-          weighted_x_i <- w_m_i * z_i[, c(1L, 2L, j_covariates)]
-          weighted_m_i <- w_m_i * z_i[, 4L]
-          coef_m_i <- solve(crossprod(weighted_x_i)) %*%
-            crossprod(weighted_x_i, weighted_m_i)
-          # compute coefficients from weighted regression y ~ m + x + covariates
-          weighted_mx_i <- w_y_i * z_i[, c(1L, 4L, 2L, j_covariates)]
-          weighted_y_i <- w_y_i * z_i[, 3L]
-          coef_y_i <- solve(crossprod(weighted_mx_i)) %*%
-            crossprod(weighted_mx_i, weighted_y_i)
-          # compute corrected coefficients
-          coef_m_i <- drop(coef_m + corr_m %*% (coef_m_i - coef_m))
-          coef_y_i <- drop(coef_y + corr_y %*% (coef_y_i - coef_y))
-          # compute effects
-          a <- unname(coef_m_i[2L])
-          b <- unname(coef_y_i[2L])
-          c <- unname(coef_y_i[3L])
-          ab <- a * b
-          c_prime <- ab + c
-          # compute effects of control variables if they exist
-          covariates <- unname(coef_y_i[-(1L:3L)])
-          # return effects
-          c(ab, a, b, c, c_prime, covariates)
+      if (fit$median) {
+
+        # define function for standard bootstrap for median regression
+        if (p_m == 1L)  {
+          # only one mediator
+          median_bootstrap <- function(z, i) {
+            # extract bootstrap sample from the data
+            z_i <- z[i, , drop = FALSE]
+            # compute coefficients from regression m ~ x + covariates
+            x_i <- z_i[, c(1L, 2L, j_covariates)]
+            m_i <- z_i[, 4L]
+            coef_m_i <- rq.fit(x_i, m_i, tau = 0.5)$coefficients
+            # compute coefficients from regression y ~ m + x + covariates
+            mx_i <- z_i[, c(1L, 4L, 2L, j_covariates)]
+            y_i <- z_i[, 3L]
+            coef_y_i <- rq.fit(mx_i, y_i, tau = 0.5)$coefficients
+            # compute effects
+            a <- unname(coef_m_i[2L])
+            b <- unname(coef_y_i[2L])
+            c <- unname(coef_y_i[3L])
+            ab <- a * b
+            c_prime <- ab + c
+            # compute effects of control variables if they exist
+            covariates <- unname(coef_y_i[-seq_len(3L)])
+            # return effects
+            c(ab, a, b, c, c_prime, covariates)
+          }
+        } else{
+          # multiple mediators
+          median_bootstrap <- function(z, i) {
+            # extract bootstrap sample from the data
+            z_i <- z[i, , drop = FALSE]
+            # compute coefficients from regressions m ~ x + covariates
+            x_i <- z_i[, c(1L, 2L, j_covariates)]
+            m_i <- z_i[, j_m]
+            coef_m_i <- sapply(j_m, function(j) {
+              m_i <- z_i[, j]
+              coef_m_i <- rq.fit(x_i, m_i, tau = 0.5)$coefficients
+            })
+            # compute coefficients from regression y ~ m + x + covariates
+            mx_i <- z_i[, c(1L, j_m, 2L, j_covariates)]
+            y_i <- z_i[, 3L]
+            coef_y_i <- rq.fit(mx_i, y_i, tau = 0.5)$coefficients
+            # compute effects
+            a <- unname(coef_m_i[2L, ])
+            b <- unname(coef_y_i[1L + seq_len(p_m)])
+            c <- unname(coef_y_i[2L + p_m])
+            ab <- a * b
+            sum_ab <- sum(ab)
+            c_prime <- sum_ab + c
+            # compute effects of control variables if they exist
+            covariates <- unname(coef_y_i[-seq_len(2L + p_m)])
+            # return effects
+            c(sum_ab, ab, a, b, c, c_prime, covariates)
+          }
         }
+        # perform standard bootstrap
+        bootstrap <- local_boot(z, median_bootstrap, R = R, ...)
+        R <- nrow(bootstrap$t)  # make sure that number of replicates is correct
+
       } else {
-        # multiple mediators
-        # extract (square root of) robustness weights and combine data
-        w_m <- sqrt(sapply(fit_mx, weights, type = "robustness"))
-        w_y <- sqrt(weights(fit_ymx, type = "robustness"))
-        z <- cbind(rep.int(1, n), as.matrix(fit$data))
-        # compute matrices for linear corrections
-        corr_m <- lapply(fit$m, function(m, z) {
-          correction_matrix(z, weights = w_m[, m],
-                            residuals = residuals(fit_mx[[m]]),
-                            scale = fit_mx[[m]]$scale,
-                            control = psi_control)
-        }, z = z[, c(1L, 2L, j_covariates)])
-        coef_m <- lapply(fit_mx, coef)
-        corr_y <- correction_matrix(z[, c(1L, j_m, 2L, j_covariates)],
-                                    weights = w_y,
-                                    residuals = residuals(fit_ymx),
-                                    scale = fit_ymx$scale,
-                                    control = psi_control)
-        coef_y <- coef(fit_ymx)
-        # perform fast and robust bootstrap
-        robust_bootstrap <- function(z, i, w_m, corr_m, coef_m,
-                                     w_y, corr_y, coef_y) {
-          # extract bootstrap sample from the data
-          z_i <- z[i, , drop = FALSE]
-          w_m_i <- w_m[i, , drop = FALSE]
-          w_y_i <- w_y[i]
-          # check whether there are enough observations with nonzero weights
-          if(any(colSums(w_m_i > 0) <= 2) || sum(w_y_i > 0) <= 3) return(NA)
-          # compute coefficients from weighted regression m ~ x + covariates
-          coef_m_i <- lapply(fit$m, function(m, x_i) {
-            w_i <- w_m_i[, m]
-            weighted_x_i <- w_i * x_i
-            weighted_m_i <- w_i * z_i[, m]
+
+        # This implementation uses the simpler approximation of
+        # Salibian-Barrera & Van Aelst (2008) rather than that of
+        # Salibian-Barrera & Zamar (2002).  The difference is that
+        # the latter also requires a correction of the residual scale.
+
+        # extract regression models
+        fit_mx <- fit$fit_mx
+        fit_ymx <- fit$fit_ymx
+        # extract control object from robust regressions
+        # (necessary to compute correction matrices)
+        psi_control <- get_psi_control(fit_ymx)  # the same for all model fits
+        if (p_m == 1L) {
+          # only one mediator
+          # extract (square root of) robustness weights and combine data
+          w_m <- sqrt(weights(fit_mx, type = "robustness"))
+          w_y <- sqrt(weights(fit_ymx, type = "robustness"))
+          # compute matrices for linear corrections
+          corr_m <- correction_matrix(z[, c(1L, 2L, j_covariates)],
+                                      weights = w_m,
+                                      residuals = residuals(fit_mx),
+                                      scale = fit_mx$scale,
+                                      control = psi_control)
+          coef_m <- coef(fit_mx)
+          corr_y <- correction_matrix(z[, c(1L, 4L, 2L, j_covariates)],
+                                      weights = w_y,
+                                      residuals = residuals(fit_ymx),
+                                      scale = fit_ymx$scale,
+                                      control = psi_control)
+          coef_y <- coef(fit_ymx)
+          # perform fast and robust bootstrap
+          robust_bootstrap <- function(z, i, w_m, corr_m, coef_m,
+                                       w_y, corr_y, coef_y) {
+            # extract bootstrap sample from the data
+            z_i <- z[i, , drop = FALSE]
+            w_m_i <- w_m[i]
+            w_y_i <- w_y[i]
+            # check whether there are enough observations with nonzero weights
+            if(sum(w_m_i > 0) <= 2 || sum(w_y_i > 0) <= 3) return(NA)
+            # compute coefficients from weighted regression m ~ x + covariates
+            weighted_x_i <- w_m_i * z_i[, c(1L, 2L, j_covariates)]
+            weighted_m_i <- w_m_i * z_i[, 4L]
             coef_m_i <- solve(crossprod(weighted_x_i)) %*%
               crossprod(weighted_x_i, weighted_m_i)
-          }, x_i = z_i[, c(1L, 2L, j_covariates)])
-          # compute coefficients from weighted regression y ~ m + x + covariates
-          weighted_mx_i <- w_y_i * z_i[, c(1L, j_m, 2L, j_covariates)]
-          weighted_y_i <- w_y_i * z_i[, 3L]
-          coef_y_i <- solve(crossprod(weighted_mx_i)) %*%
-            crossprod(weighted_mx_i, weighted_y_i)
-          # compute corrected coefficients
-          coef_m_i <- mapply(function(coef_m, coef_m_i, corr_m) {
-            drop(coef_m + corr_m %*% (coef_m_i - coef_m))
-          }, coef_m = coef_m, coef_m_i = coef_m_i, corr_m = corr_m)
-          coef_y_i <- drop(coef_y + corr_y %*% (coef_y_i - coef_y))
-          # compute effects
-          a <- unname(coef_m_i[2L, ])
-          b <- unname(coef_y_i[1L + seq_len(p_m)])
-          c <- unname(coef_y_i[2L + p_m])
-          ab <- a * b
-          sum_ab <- sum(ab)
-          c_prime <- sum_ab + c
-          # compute effects of control variables if they exist
-          covariates <- unname(coef_y_i[-seq_len(2L + p_m)])
-          # return effects
-          c(sum_ab, ab, a, b, c, c_prime, covariates)
+            # compute coefficients from weighted regression y ~ m + x + covariates
+            weighted_mx_i <- w_y_i * z_i[, c(1L, 4L, 2L, j_covariates)]
+            weighted_y_i <- w_y_i * z_i[, 3L]
+            coef_y_i <- solve(crossprod(weighted_mx_i)) %*%
+              crossprod(weighted_mx_i, weighted_y_i)
+            # compute corrected coefficients
+            coef_m_i <- drop(coef_m + corr_m %*% (coef_m_i - coef_m))
+            coef_y_i <- drop(coef_y + corr_y %*% (coef_y_i - coef_y))
+            # compute effects
+            a <- unname(coef_m_i[2L])
+            b <- unname(coef_y_i[2L])
+            c <- unname(coef_y_i[3L])
+            ab <- a * b
+            c_prime <- ab + c
+            # compute effects of control variables if they exist
+            covariates <- unname(coef_y_i[-(1L:3L)])
+            # return effects
+            c(ab, a, b, c, c_prime, covariates)
+          }
+        } else {
+          # multiple mediators
+          # extract (square root of) robustness weights and combine data
+          w_m <- sqrt(sapply(fit_mx, weights, type = "robustness"))
+          w_y <- sqrt(weights(fit_ymx, type = "robustness"))
+          z <- cbind(rep.int(1, n), as.matrix(fit$data))
+          # compute matrices for linear corrections
+          corr_m <- lapply(fit$m, function(m, z) {
+            correction_matrix(z, weights = w_m[, m],
+                              residuals = residuals(fit_mx[[m]]),
+                              scale = fit_mx[[m]]$scale,
+                              control = psi_control)
+          }, z = z[, c(1L, 2L, j_covariates)])
+          coef_m <- lapply(fit_mx, coef)
+          corr_y <- correction_matrix(z[, c(1L, j_m, 2L, j_covariates)],
+                                      weights = w_y,
+                                      residuals = residuals(fit_ymx),
+                                      scale = fit_ymx$scale,
+                                      control = psi_control)
+          coef_y <- coef(fit_ymx)
+          # perform fast and robust bootstrap
+          robust_bootstrap <- function(z, i, w_m, corr_m, coef_m,
+                                       w_y, corr_y, coef_y) {
+            # extract bootstrap sample from the data
+            z_i <- z[i, , drop = FALSE]
+            w_m_i <- w_m[i, , drop = FALSE]
+            w_y_i <- w_y[i]
+            # check whether there are enough observations with nonzero weights
+            if(any(colSums(w_m_i > 0) <= 2) || sum(w_y_i > 0) <= 3) return(NA)
+            # compute coefficients from weighted regression m ~ x + covariates
+            coef_m_i <- lapply(fit$m, function(m, x_i) {
+              w_i <- w_m_i[, m]
+              weighted_x_i <- w_i * x_i
+              weighted_m_i <- w_i * z_i[, m]
+              coef_m_i <- solve(crossprod(weighted_x_i)) %*%
+                crossprod(weighted_x_i, weighted_m_i)
+            }, x_i = z_i[, c(1L, 2L, j_covariates)])
+            # compute coefficients from weighted regression y ~ m + x + covariates
+            weighted_mx_i <- w_y_i * z_i[, c(1L, j_m, 2L, j_covariates)]
+            weighted_y_i <- w_y_i * z_i[, 3L]
+            coef_y_i <- solve(crossprod(weighted_mx_i)) %*%
+              crossprod(weighted_mx_i, weighted_y_i)
+            # compute corrected coefficients
+            coef_m_i <- mapply(function(coef_m, coef_m_i, corr_m) {
+              drop(coef_m + corr_m %*% (coef_m_i - coef_m))
+            }, coef_m = coef_m, coef_m_i = coef_m_i, corr_m = corr_m)
+            coef_y_i <- drop(coef_y + corr_y %*% (coef_y_i - coef_y))
+            # compute effects
+            a <- unname(coef_m_i[2L, ])
+            b <- unname(coef_y_i[1L + seq_len(p_m)])
+            c <- unname(coef_y_i[2L + p_m])
+            ab <- a * b
+            sum_ab <- sum(ab)
+            c_prime <- sum_ab + c
+            # compute effects of control variables if they exist
+            covariates <- unname(coef_y_i[-seq_len(2L + p_m)])
+            # return effects
+            c(sum_ab, ab, a, b, c, c_prime, covariates)
+          }
         }
+        # perform fast and robust bootstrap
+        bootstrap <- local_boot(z, robust_bootstrap, R = R, w_m = w_m,
+                                corr_m = corr_m, coef_m = coef_m, w_y = w_y,
+                                corr_y = corr_y, coef_y = coef_y, ...)
+        R <- colSums(!is.na(bootstrap$t))  # adjust number of replicates for NAs
+
       }
-      # perform fast and robust bootstrap
-      bootstrap <- local_boot(z, robust_bootstrap, R = R, w_m = w_m,
-                              corr_m = corr_m, coef_m = coef_m, w_y = w_y,
-                              corr_y = corr_y, coef_y = coef_y, ...)
-      R <- colSums(!is.na(bootstrap$t))  # adjust number of replicates for NAs
 
     } else {
 
       # define function for standard bootstrap mediation test
-      if(p_m == 1L)  {
+      if (p_m == 1L)  {
         # only one mediator
         standard_bootstrap <- function(z, i) {
           # extract bootstrap sample from the data
-          z_i <- z[i, , drop=FALSE]
+          z_i <- z[i, , drop = FALSE]
           # compute coefficients from regression m ~ x + covariates
           x_i <- z_i[, c(1L, 2L, j_covariates)]
           m_i <- z_i[, 4L]
@@ -424,7 +513,7 @@ boot_test_mediation <- function(fit,
         # multiple mediators
         standard_bootstrap <- function(z, i) {
           # extract bootstrap sample from the data
-          z_i <- z[i, , drop=FALSE]
+          z_i <- z[i, , drop = FALSE]
           # compute coefficients from regressions m ~ x + covariates
           x_i <- z_i[, c(1L, 2L, j_covariates)]
           m_i <- z_i[, j_m]
@@ -451,7 +540,7 @@ boot_test_mediation <- function(fit,
         }
       }
       # perform standard bootstrap
-      bootstrap <- local_boot(z, standard_bootstrap, R=R, ...)
+      bootstrap <- local_boot(z, standard_bootstrap, R = R, ...)
       R <- nrow(bootstrap$t)  # make sure that number of replicates is correct
     }
 
